@@ -327,7 +327,7 @@ class SARIFFormatter(BaseFormatter):
                 full_description=sarif.MultiformatMessageString(
                     text=rules_map[rule_id].description
                 ),
-                help_uri=rules_map[rule_id].source_url if rules_map[rule_id] else None
+                help_uri=rules_map[rule_id].source_url if rules_map[rule_id] else 'https://github.com/aws-cloudformation/cfn-lint/blob/main/docs/rules.md'
             )
             for rule_id in matched_rules
         ]
