@@ -10,7 +10,7 @@ class ImportValue(CloudFormationLintRule):
     """Check if ImportValue values are correct"""
     id = 'E1016'
     shortdesc = 'ImportValue validation of parameters'
-    description = 'Making sure the function not is of list'
+    description = 'Making sure the ImportValue function is properly configured'
     source_url = 'https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/intrinsic-function-reference-importvalue.html'
     tags = ['functions', 'importvalue']
 
